==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_entities/equipmentcategory_001/EquipmentCategory.java <==

package net.datastream.schemas.mp_entities.equipmentcategory_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CATEGORYID;
import net.datastream.schemas.mp_fields.CLASSID_Type;
import net.datastream.schemas.mp_fields.MANUFACTURERID_Type;
import net.datastream.schemas.mp_fields.USERDEFINEDAREA;
import net.datastream.schemas.mp_fields.USERDEFINEDCODEID_Type;
import net.datastream.schemas.mp_fields.USERID_Type;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CATEGORYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLASSID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MANUFACTURERID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERDEFINEDAREA" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SAFETYDATEREVIEWREQUIRED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SAFETYREVIEWEDBY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PERMITDATEREVIEWREQUIRED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PERMITREVIEWEDBY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SCHEMATICID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PIDNUMBER" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PIDDRAWING" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *       &lt;attribute name="user_entity" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="system_entity" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "categoryid",
    "classid",
    "manufacturerid",
    "userdefinedarea",
    "safetydatereviewrequired",
    "safetyreviewedby",
    "permitdatereviewrequired",
    "permitreviewedby",
    "schematicid",
    "pidnumber",
    "piddrawing"
})
@XmlRootElement(name = "EquipmentCategory")
public class EquipmentCategory {

    @XmlElement(name = "CATEGORYID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected CATEGORYID categoryid;
    @XmlElement(name = "CLASSID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected CLASSID_Type classid;
    @XmlElement(name = "MANUFACTURERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected MANUFACTURERID_Type manufacturerid;
    @XmlElement(name = "USERDEFINEDAREA", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERDEFINEDAREA userdefinedarea;
    @XmlElement(name = "SAFETYDATEREVIEWREQUIRED", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME safetydatereviewrequired;
    @XmlElement(name = "SAFETYREVIEWEDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type safetyreviewedby;
    @XmlElement(name = "PERMITDATEREVIEWREQUIRED", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME permitdatereviewrequired;
    @XmlElement(name = "PERMITREVIEWEDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type permitreviewedby;
    @XmlElement(name = "SCHEMATICID", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERDEFINEDCODEID_Type schematicid;
    @XmlElement(name = "PIDNUMBER", namespace = "http://schemas.datastream.net/MP_fields")
    protected String pidnumber;
    @XmlElement(name = "PIDDRAWING", namespace = "http://schemas.datastream.net/MP_fields")
    protected String piddrawing;
    @XmlAttribute(name = "recordid")
    protected Long recordid;
    @XmlAttribute(name = "user_entity")
    protected String user_Entity;
    @XmlAttribute(name = "system_entity")
    protected String system_Entity;

    /**
     * Gets the value of the categoryid property.
     * 
     * @return
     *     possible object is
     *     {@link CATEGORYID }
     *     
     */
    public CATEGORYID getCATEGORYID() {
        return categoryid;
    }

    /**
     * Sets the value of the categoryid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CATEGORYID }
     *     
     */
    public void setCATEGORYID(CATEGORYID value) {
        this.categoryid = value;
    }

    /**
     * Gets the value of the classid property.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getCLASSID() {
        return classid;
    }

    /**
     * Sets the value of the classid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setCLASSID(CLASSID_Type value) {
        this.classid = value;
    }

    /**
     * Gets the value of the manufacturerid property.
     * 
     * @return
     *     possible object is
     *     {@link MANUFACTURERID_Type }
     *     
     */
    public MANUFACTURERID_Type getMANUFACTURERID() {
        return manufacturerid;
    }

    /**
     * Sets the value of the manufacturerid property.
     * 
     * @param value
     *     allowed object is
     *     {@link MANUFACTURERID_Type }
     *     
     */
    public void setMANUFACTURERID(MANUFACTURERID_Type value) {
        this.manufacturerid = value;
    }

    /**
     * Gets the value of the userdefinedarea property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDAREA }
     *     
     */
    public USERDEFINEDAREA getUSERDEFINEDAREA() {
        return userdefinedarea;
    }

    /**
     * Sets the value of the userdefinedarea property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDAREA }
     *     
     */
    public void setUSERDEFINEDAREA(USERDEFINEDAREA value) {
        this.userdefinedarea = value;
    }

    /**
     * Gets the value of the safetydatereviewrequired property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getSAFETYDATEREVIEWREQUIRED() {
        return safetydatereviewrequired;
    }

    /**
     * Sets the value of the safetydatereviewrequired property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setSAFETYDATEREVIEWREQUIRED(DATETIME value) {
        this.safetydatereviewrequired = value;
    }

    /**
     * Gets the value of the safetyreviewedby property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getSAFETYREVIEWEDBY() {
        return safetyreviewedby;
    }

    /**
     * Sets the value of the safetyreviewedby property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setSAFETYREVIEWEDBY(USERID_Type value) {
        this.safetyreviewedby = value;
    }

    /**
     * Gets the value of the permitdatereviewrequired property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getPERMITDATEREVIEWREQUIRED() {
        return permitdatereviewrequired;
    }

    /**
     * Sets the value of the permitdatereviewrequired property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setPERMITDATEREVIEWREQUIRED(DATETIME value) {
        this.permitdatereviewrequired = value;
    }

    /**
     * Gets the value of the permitreviewedby property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getPERMITREVIEWEDBY() {
        return permitreviewedby;
    }

    /**
     * Sets the value of the permitreviewedby property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setPERMITREVIEWEDBY(USERID_Type value) {
        this.permitreviewedby = value;
    }

    /**
     * Gets the value of the schematicid property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getSCHEMATICID() {
        return schematicid;
    }

    /**
     * Sets the value of the schematicid property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setSCHEMATICID(USERDEFINEDCODEID_Type value) {
        this.schematicid = value;
    }

    /**
     * Gets the value of the pidnumber property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPIDNUMBER() {
        return pidnumber;
    }

    /**
     * Sets the value of the pidnumber property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPIDNUMBER(String value) {
        this.pidnumber = value;
    }

    /**
     * Gets the value of the piddrawing property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPIDDRAWING() {
        return piddrawing;
    }

    /**
     * Sets the value of the piddrawing property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPIDDRAWING(String value) {
        this.piddrawing = value;
    }

    /**
     * Gets the value of the recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Sets the value of the recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

    /**
     * Gets the value of the user_Entity property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUser_Entity() {
        return user_Entity;
    }

    /**
     * Sets the value of the user_Entity property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUser_Entity(String value) {
        this.user_Entity = value;
    }

    /**
     * Gets the value of the system_Entity property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSystem_Entity() {
        return system_Entity;
    }

    /**
     * Sets the value of the system_Entity property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSystem_Entity(String value) {
        this.system_Entity = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_entities/equipmentcategory_001/EquipmentCategory.java <==

package net.datastream.schemas.mp_entities.equipmentcategory_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CATEGORYID;
import net.datastream.schemas.mp_fields.CLASSID_Type;
import net.datastream.schemas.mp_fields.MANUFACTURERID_Type;
import net.datastream.schemas.mp_fields.USERDEFINEDAREA;
import net.datastream.schemas.mp_fields.USERDEFINEDCODEID_Type;
import net.datastream.schemas.mp_fields.USERID_Type;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CATEGORYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLASSID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MANUFACTURERID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERDEFINEDAREA" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SAFETYDATEREVIEWREQUIRED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SAFETYREVIEWEDBY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PERMITDATEREVIEWREQUIRED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PERMITREVIEWEDBY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SCHEMATICID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PIDNUMBER" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PIDDRAWING" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACCOUNTSEGMENTVALUE" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *       &lt;attribute name="user_entity" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="system_entity" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "categoryid",
    "classid",
    "manufacturerid",
    "userdefinedarea",
    "safetydatereviewrequired",
    "safetyreviewedby",
    "permitdatereviewrequired",
    "permitreviewedby",
    "schematicid",
    "pidnumber",
    "piddrawing",
    "accountsegmentvalue"
})
@XmlRootElement(name = "EquipmentCategory")
public class EquipmentCategory {

    @XmlElement(name = "CATEGORYID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected CATEGORYID categoryid;
    @XmlElement(name = "CLASSID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected CLASSID_Type classid;
    @XmlElement(name = "MANUFACTURERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected MANUFACTURERID_Type manufacturerid;
    @XmlElement(name = "USERDEFINEDAREA", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERDEFINEDAREA userdefinedarea;
    @XmlElement(name = "SAFETYDATEREVIEWREQUIRED", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME safetydatereviewrequired;
    @XmlElement(name = "SAFETYREVIEWEDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type safetyreviewedby;
    @XmlElement(name = "PERMITDATEREVIEWREQUIRED", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME permitdatereviewrequired;
    @XmlElement(name = "PERMITREVIEWEDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type permitreviewedby;
    @XmlElement(name = "SCHEMATICID", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERDEFINEDCODEID_Type schematicid;
    @XmlElement(name = "PIDNUMBER", namespace = "http://schemas.datastream.net/MP_fields")
    protected String pidnumber;
    @XmlElement(name = "PIDDRAWING", namespace = "http://schemas.datastream.net/MP_fields")
    protected String piddrawing;
    @XmlElement(name = "ACCOUNTSEGMENTVALUE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String accountsegmentvalue;
    @XmlAttribute(name = "recordid")
    protected Long recordid;
    @XmlAttribute(name = "user_entity")
    protected String user_Entity;
    @XmlAttribute(name = "system_entity")
    protected String system_Entity;

    /**
     * Gets the value of the categoryid property.
     * 
     * @return
     *     possible object is
     *     {@link CATEGORYID }
     *     
     */
    public CATEGORYID getCATEGORYID() {
        return categoryid;
    }

    /**
     * Sets the value of the categoryid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CATEGORYID }
     *     
     */
    public void setCATEGORYID(CATEGORYID value) {
        this.categoryid = value;
    }

    /**
     * Gets the value of the classid property.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getCLASSID() {
        return classid;
    }

    /**
     * Sets the value of the classid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setCLASSID(CLASSID_Type value) {
        this.classid = value;
    }

    /**
     * Gets the value of the manufacturerid property.
     * 
     * @return
     *     possible object is
     *     {@link MANUFACTURERID_Type }
     *     
     */
    public MANUFACTURERID_Type getMANUFACTURERID() {
        return manufacturerid;
    }

    /**
     * Sets the value of the manufacturerid property.
     * 
     * @param value
     *     allowed object is
     *     {@link MANUFACTURERID_Type }
     *     
     */
    public void setMANUFACTURERID(MANUFACTURERID_Type value) {
        this.manufacturerid = value;
    }

    /**
     * Gets the value of the userdefinedarea property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDAREA }
     *     
     */
    public USERDEFINEDAREA getUSERDEFINEDAREA() {
        return userdefinedarea;
    }

    /**
     * Sets the value of the userdefinedarea property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDAREA }
     *     
     */
    public void setUSERDEFINEDAREA(USERDEFINEDAREA value) {
        this.userdefinedarea = value;
    }

    /**
     * Gets the value of the safetydatereviewrequired property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getSAFETYDATEREVIEWREQUIRED() {
        return safetydatereviewrequired;
    }

    /**
     * Sets the value of the safetydatereviewrequired property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setSAFETYDATEREVIEWREQUIRED(DATETIME value) {
        this.safetydatereviewrequired = value;
    }

    /**
     * Gets the value of the safetyreviewedby property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getSAFETYREVIEWEDBY() {
        return safetyreviewedby;
    }

    /**
     * Sets the value of the safetyreviewedby property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setSAFETYREVIEWEDBY(USERID_Type value) {
        this.safetyreviewedby = value;
    }

    /**
     * Gets the value of the permitdatereviewrequired property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getPERMITDATEREVIEWREQUIRED() {
        return permitdatereviewrequired;
    }

    /**
     * Sets the value of the permitdatereviewrequired property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setPERMITDATEREVIEWREQUIRED(DATETIME value) {
        this.permitdatereviewrequired = value;
    }

    /**
     * Gets the value of the permitreviewedby property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getPERMITREVIEWEDBY() {
        return permitreviewedby;
    }

    /**
     * Sets the value of the permitreviewedby property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setPERMITREVIEWEDBY(USERID_Type value) {
        this.permitreviewedby = value;
    }

    /**
     * Gets the value of the schematicid property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getSCHEMATICID() {
        return schematicid;
    }

    /**
     * Sets the value of the schematicid property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setSCHEMATICID(USERDEFINEDCODEID_Type value) {
        this.schematicid = value;
    }

    /**
     * Gets the value of the pidnumber property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPIDNUMBER() {
        return pidnumber;
    }

    /**
     * Sets the value of the pidnumber property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPIDNUMBER(String value) {
        this.pidnumber = value;
    }

    /**
     * Gets the value of the piddrawing property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPIDDRAWING() {
        return piddrawing;
    }

    /**
     * Sets the value of the piddrawing property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPIDDRAWING(String value) {
        this.piddrawing = value;
    }

    /**
     * Gets the value of the accountsegmentvalue property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getACCOUNTSEGMENTVALUE() {
        return accountsegmentvalue;
    }

    /**
     * Sets the value of the accountsegmentvalue property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setACCOUNTSEGMENTVALUE(String value) {
        this.accountsegmentvalue = value;
    }

    /**
     * Gets the value of the recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Sets the value of the recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

    /**
     * Gets the value of the user_Entity property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUser_Entity() {
        return user_Entity;
    }

    /**
     * Sets the value of the user_Entity property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUser_Entity(String value) {
        this.user_Entity = value;
    }

    /**
     * Gets the value of the system_Entity property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSystem_Entity() {
        return system_Entity;
    }

    /**
     * Sets the value of the system_Entity property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSystem_Entity(String value) {
        this.system_Entity = value;
    }

}
